.. _documentation:

=============
Documentation
=============

.. htmlonly::

   :Release: |version|
   :Date: |today|

Contents:

.. toctree::
   :maxdepth: 2

   users/index
   interfaces/index
   devel/index
   changes

For bleeding-edge version see `Nightly documentation <http://www.mit.edu/~satra/nipype-nightly/>`_

.. include:: links_names.txt
